﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using MSUtil;
using System.Data;

namespace LogParser
{
    public abstract class LogParserBase
    {
        protected readonly LogParserConfig myBaseConfig;

        protected object myInputContext;

        /// <summary>
        /// 默认构造函数
        /// </summary>
        /// <param name="config"></param>
        protected LogParserBase(LogParserConfig config)
        {
            myBaseConfig = config;
        }

        /// <summary>
        /// 执行查询
        /// </summary>
        /// <param name="query"></param>
        /// <returns></returns>
        public DataTable RunQuery(string query)
        {
            DataTable dt = new DataTable();

            // 初始化LogQuery 对象
            var logQuery = new LogQueryClass();

            // 缓存输入上下文
            if (myInputContext == null)
                myInputContext = GetInputContext();
            // 执行查询   
            var oRecordSet = logQuery.Execute(query, myInputContext);
  		
            int columnCount = oRecordSet.getColumnCount();
            //取得所有的列名名称
            for (int i = 0; i < columnCount; i++)
            {
                string columnName = oRecordSet.getColumnName(i);
                dt.Columns.Add(columnName);
            }

            // 浏览记录
            for (; !oRecordSet.atEnd(); oRecordSet.moveNext())
            {
                // 获取当前的记录
                ILogRecord logRecord = oRecordSet.getRecord();             
                DataRow dr = dt.NewRow();
                for (int i = 0; i < columnCount; i++)
                {
                    string columnName = oRecordSet.getColumnName(i);
                    dr[columnName] = logRecord.getValue(columnName);
                }
                dt.Rows.Add(dr);
            }
            oRecordSet.close();
            return dt;            
        }

        protected abstract object GetInputContext();
    }
}
